# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StatedbArchivedJobLogs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'url': 'RimeSafeURL',
        'expiration_time': 'datetime'
    }

    attribute_map = {
        'url': 'url',
        'expiration_time': 'expirationTime'
    }

    def __init__(self, url=None, expiration_time=None):  # noqa: E501
        """StatedbArchivedJobLogs - a model defined in Swagger"""  # noqa: E501
        self._url = None
        self._expiration_time = None
        self.discriminator = None
        if url is not None:
            self.url = url
        if expiration_time is not None:
            self.expiration_time = expiration_time

    @property
    def url(self):
        """Gets the url of this StatedbArchivedJobLogs.  # noqa: E501


        :return: The url of this StatedbArchivedJobLogs.  # noqa: E501
        :rtype: RimeSafeURL
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this StatedbArchivedJobLogs.


        :param url: The url of this StatedbArchivedJobLogs.  # noqa: E501
        :type: RimeSafeURL
        """

        self._url = url

    @property
    def expiration_time(self):
        """Gets the expiration_time of this StatedbArchivedJobLogs.  # noqa: E501


        :return: The expiration_time of this StatedbArchivedJobLogs.  # noqa: E501
        :rtype: datetime
        """
        return self._expiration_time

    @expiration_time.setter
    def expiration_time(self, expiration_time):
        """Sets the expiration_time of this StatedbArchivedJobLogs.


        :param expiration_time: The expiration_time of this StatedbArchivedJobLogs.  # noqa: E501
        :type: datetime
        """

        self._expiration_time = expiration_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StatedbArchivedJobLogs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatedbArchivedJobLogs):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
